==> blancoNLpackGenerator-0.0.97-src.zip: src/blanco/xliff/valueobject/BlancoXliffTransUnit.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF  trans-unit 킷o[IuWFNgB
 */
public class BlancoXliffTransUnit {
    /**
     * tB[h [id]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     */
    private String fId;

    /**
     * tB[h [source]
     *
     * ڂ̌^ [java.lang.String]<br>
     */
    private String fSource;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     */
    private BlancoXliffTarget fTarget;

    /**
     * tB[h [altTransList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * alt-trans̃XgB
     */
    private List fAltTransList = new java.util.ArrayList();

    /**
     * tB[h [noteList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * notẽXgB
     */
    private List fNoteList = new java.util.ArrayList();

    /**
     * tB[h [approved]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ̖|͏FꂽǂB
     */
    private boolean fApproved = false;

    /**
     * tB[h [translate]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     */
    private boolean fTranslate = true;

    /**
     * tB[h [phase-name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     */
    private String fPhaseName;

    /**
     * tB[h [id]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     *
     * @param argId tB[h[id]Ɋi[l
     */
    public void setId(final String argId) {
        fId = argId;
    }

    /**
     * tB[h[id]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     *
     * @return tB[h[id]Ɋi[Ăl
     */
    public String getId() {
        return fId;
    }

    /**
     * tB[h [source]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argSource tB[h[source]Ɋi[l
     */
    public void setSource(final String argSource) {
        fSource = argSource;
    }

    /**
     * tB[h[source]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @return tB[h[source]Ɋi[Ăl
     */
    public String getSource() {
        return fSource;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final BlancoXliffTarget argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public BlancoXliffTarget getTarget() {
        return fTarget;
    }

    /**
     * tB[h [altTransList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * alt-trans̃XgB
     *
     * @param argAltTransList tB[h[altTransList]Ɋi[l
     */
    public void setAltTransList(final List argAltTransList) {
        fAltTransList = argAltTransList;
    }

    /**
     * tB[h[altTransList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * alt-trans̃XgB
     *
     * @return tB[h[altTransList]Ɋi[Ăl
     */
    public List getAltTransList() {
        return fAltTransList;
    }

    /**
     * tB[h [noteList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * notẽXgB
     *
     * @param argNoteList tB[h[noteList]Ɋi[l
     */
    public void setNoteList(final List argNoteList) {
        fNoteList = argNoteList;
    }

    /**
     * tB[h[noteList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * notẽXgB
     *
     * @return tB[h[noteList]Ɋi[Ăl
     */
    public List getNoteList() {
        return fNoteList;
    }

    /**
     * tB[h [approved]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * ̖|͏FꂽǂB
     *
     * @param argApproved tB[h[approved]Ɋi[l
     */
    public void setApproved(final boolean argApproved) {
        fApproved = argApproved;
    }

    /**
     * tB[h[approved]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ̖|͏FꂽǂB
     *
     * @return tB[h[approved]Ɋi[Ăl
     */
    public boolean getApproved() {
        return fApproved;
    }

    /**
     * tB[h [translate]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     *
     * @param argTranslate tB[h[translate]Ɋi[l
     */
    public void setTranslate(final boolean argTranslate) {
        fTranslate = argTranslate;
    }

    /**
     * tB[h[translate]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     *
     * @return tB[h[translate]Ɋi[Ăl
     */
    public boolean getTranslate() {
        return fTranslate;
    }

    /**
     * tB[h [phase-name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @param argPhaseName tB[h[phase-name]Ɋi[l
     */
    public void setPhaseName(final String argPhaseName) {
        fPhaseName = argPhaseName;
    }

    /**
     * tB[h[phase-name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @return tB[h[phase-name]Ɋi[Ăl
     */
    public String getPhaseName() {
        return fPhaseName;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffTransUnit[");
        buf.append("id=" + fId);
        buf.append(",source=" + fSource);
        buf.append(",target=" + fTarget);
        buf.append(",altTransList=" + fAltTransList);
        buf.append(",noteList=" + fNoteList);
        buf.append(",approved=" + fApproved);
        buf.append(",translate=" + fTranslate);
        buf.append(",phase-name=" + fPhaseName);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/xliff/valueobject/BlancoXliffTransUnit.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

import java.util.List;

/**
 * OASIS XLIFF  trans-unit 킷o[IuWFNgB
 */
public class BlancoXliffTransUnit {
    /**
     * tB[h [id]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     */
    private String fId;

    /**
     * tB[h [source]
     *
     * ڂ̌^ [java.lang.String]<br>
     */
    private String fSource;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     */
    private BlancoXliffTarget fTarget;

    /**
     * tB[h [altTransList]
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffAltTrans>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffAltTrans>()]<br>
     * alt-trans̃XgB
     */
    private List<blanco.xliff.valueobject.BlancoXliffAltTrans> fAltTransList = new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffAltTrans>();

    /**
     * tB[h [noteList]
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>()]<br>
     * notẽXgB
     */
    private List<blanco.xliff.valueobject.BlancoXliffNote> fNoteList = new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>();

    /**
     * tB[h [approved]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ̖|͏FꂽǂB
     */
    private boolean fApproved = false;

    /**
     * tB[h [translate]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     */
    private boolean fTranslate = true;

    /**
     * tB[h [phase-name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     */
    private String fPhaseName;

    /**
     * tB[h [id]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     *
     * @param argId tB[h[id]Ɋi[l
     */
    public void setId(final String argId) {
        fId = argId;
    }

    /**
     * tB[h[id]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |󃆃jbgIDB
     *
     * @return tB[h[id]Ɋi[Ăl
     */
    public String getId() {
        return fId;
    }

    /**
     * tB[h [source]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argSource tB[h[source]Ɋi[l
     */
    public void setSource(final String argSource) {
        fSource = argSource;
    }

    /**
     * tB[h[source]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @return tB[h[source]Ɋi[Ăl
     */
    public String getSource() {
        return fSource;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final BlancoXliffTarget argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [blanco.xliff.valueobject.BlancoXliffTarget]<br>
     * |󃆃jbg̃^[QbgB
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public BlancoXliffTarget getTarget() {
        return fTarget;
    }

    /**
     * tB[h [altTransList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffAltTrans>]<br>
     * alt-trans̃XgB
     *
     * @param argAltTransList tB[h[altTransList]Ɋi[l
     */
    public void setAltTransList(final List<blanco.xliff.valueobject.BlancoXliffAltTrans> argAltTransList) {
        fAltTransList = argAltTransList;
    }

    /**
     * tB[h[altTransList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffAltTrans>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffAltTrans>()]<br>
     * alt-trans̃XgB
     *
     * @return tB[h[altTransList]Ɋi[Ăl
     */
    public List<blanco.xliff.valueobject.BlancoXliffAltTrans> getAltTransList() {
        return fAltTransList;
    }

    /**
     * tB[h [noteList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * notẽXgB
     *
     * @param argNoteList tB[h[noteList]Ɋi[l
     */
    public void setNoteList(final List<blanco.xliff.valueobject.BlancoXliffNote> argNoteList) {
        fNoteList = argNoteList;
    }

    /**
     * tB[h[noteList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.xliff.valueobject.BlancoXliffNote>]<br>
     * Kl   [new java.util.ArrayList<blanco.xliff.valueobject.BlancoXliffNote>()]<br>
     * notẽXgB
     *
     * @return tB[h[noteList]Ɋi[Ăl
     */
    public List<blanco.xliff.valueobject.BlancoXliffNote> getNoteList() {
        return fNoteList;
    }

    /**
     * tB[h [approved]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * ̖|͏FꂽǂB
     *
     * @param argApproved tB[h[approved]Ɋi[l
     */
    public void setApproved(final boolean argApproved) {
        fApproved = argApproved;
    }

    /**
     * tB[h[approved]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ̖|͏FꂽǂB
     *
     * @return tB[h[approved]Ɋi[Ăl
     */
    public boolean getApproved() {
        return fApproved;
    }

    /**
     * tB[h [translate]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     *
     * @param argTranslate tB[h[translate]Ɋi[l
     */
    public void setTranslate(final boolean argTranslate) {
        fTranslate = argTranslate;
    }

    /**
     * tB[h[translate]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * eLXg|󂷂ׂǂtOBfalse ̏ꍇ͖|ΏۊOɑB
     *
     * @return tB[h[translate]Ɋi[Ăl
     */
    public boolean getTranslate() {
        return fTranslate;
    }

    /**
     * tB[h [phase-name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @param argPhaseName tB[h[phase-name]Ɋi[l
     */
    public void setPhaseName(final String argPhaseName) {
        fPhaseName = argPhaseName;
    }

    /**
     * tB[h[phase-name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @return tB[h[phase-name]Ɋi[Ăl
     */
    public String getPhaseName() {
        return fPhaseName;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffTransUnit[");
        buf.append("id=" + fId);
        buf.append(",source=" + fSource);
        buf.append(",target=" + fTarget);
        buf.append(",altTransList=" + fAltTransList);
        buf.append(",noteList=" + fNoteList);
        buf.append(",approved=" + fApproved);
        buf.append(",translate=" + fTranslate);
        buf.append(",phase-name=" + fPhaseName);
        buf.append("]");
        return buf.toString();
    }
}
